@@ -1,8 +1,15 @@
-from .exceptions import DecryptError, EncryptError, PysetoError, SignError, VerifyError
+from .exceptions import (
+    DecryptError,
+    EncryptError,
+    NotSupportedError,
+    PysetoError,
+    SignError,
+    VerifyError,
+)
 from .key import Key
 from .pyseto import decode, encode
 
-__version__ = "0.2.0"
+__version__ = "0.3.1"
 __title__ = "PySETO"
 __description__ = "A Python implementation of PASETO"
 __url__ = "https://pyseto.readthedocs.io"
@@ -17,8 +24,9 @@ __all__ = [
     "decode",
     "Key",
     "PysetoError",
+    "DecryptError",
+    "EncryptError",
+    "NotSupportedError",
     "SignError",
     "VerifyError",
-    "EncryptError",
-    "DecryptError",
 ]
